for func_name, func in pairs(PlayerOptions) do
	PlayerOptions[func_name:lower()]= func
end

local poptions= {}
for i, pn in ipairs(GAMESTATE:GetEnabledPlayers()) do
	poptions[pn]= GAMESTATE:GetPlayerState(pn):GetPlayerOptions("ModsLevel_Song")
end

local float_mods= {
	"Boost", "Brake", "Wave", "Expand", "Boomerang", "Drunk", "Dizzy",
	"Confusion", "Mini", "Tiny", "Flip", "Invert", "Tornado", "Tipsy",
	"Bumpy", "Beat", "Xmode", "Twirl", "Roll", "Hidden", "HiddenOffset",
	"Sudden", "SuddenOffset", "Stealth", "Blink", "RandomVanish", "Reverse",
	"Split", "Alternate", "Cross", "Centered", "Dark", "Blind", "Cover",
	"RandAttack", "NoAttack", "PlayerAutoPlay", "Tilt", "Skew", "Passmark",
	"RandomSpeed",
}
local function clear_mods(pn)
	poptions[pn]:XMod(1)
	for i, mod in ipairs(float_mods) do
		poptions[pn][mod](poptions[pn], 0)
	end
end

local num_chars= {["-"]= true}
for i= 0, 9 do num_chars[tostring(i)]= true end

local function apply_mod(mod, pn)
	mod= mod:lower()
	local sub_mods= split(",", mod)
	for i, sub in ipairs(sub_mods) do
		local level= 1
		local speed= 1
		local parts= split(" ", sub)
		for p, par in ipairs(parts) do
			local first_char= par:sub(1, 1)
			if par == "no" then
				level= 0
			else
				local before_num, num, after_num= par:match("(*?)([%d%-%.]+)([x%%%*]?)")
				num= tonumber(num)
				if num and after_num ~= "x" then
					if before_num == "*" or after_num == "*" then
						speed= num
					else
						level= num / 100
					end
				end
			end
		end
		local mod_name= parts[#parts]
		if PlayerOptions[mod_name] then
			poptions[pn][mod_name](poptions[pn], level, speed)
		elseif mod_name == "clearall" then
			clear_mods(pn)
		else
			local corm, value, xm= mod_name:match("([cm]?)([%d%-%.]+)(x?)")
			value= tonumber(value)
			if xm == "x" then
				poptions[pn]:XMod(value, speed)
			elseif corm == "c" then
				poptions[pn]:CMod(value, speed)
			elseif corm == "m" then
				poptions[pn]:MMod(value, speed)
			end
		end
	end
end

local function mod_both(mod)
	for pn, ops in pairs(poptions) do
		apply_mod(mod, pn, false)
	end
end

local thing_actors= {}
local modEffect= 1
local skewdir= -.1
local p1skew= .1
local fgcurcommand= 1
local checked= false
local curmod= 1

--lua course D:	/ timed mod management	
--{beat,mod,player}
local mods = {
	{0.01,'*1000 clearall,*2000 2x,*2000 -1000 cover'},

	--speech1
	{16.750,'*1000 80 stealth'},
	{16.85,'*6 0 stealth'},

	{17.50,'*1000 80 stealth'},
	{17.60,'*2 0 stealth'},


	{19.50,'*1000 80 stealth'},
	{19.60,'*2 0 stealth'},


	{21.00,'*1000 80 stealth'},
	{21.10,'*6 0 stealth'},

	{21.50,'*1000 80 stealth'},
	{21.60,'*3 0 stealth'},

	{22.00,'*1000 80 stealth'},
	{22.10,'*6 0 stealth'},

	{22.25,'*1000 80 stealth'},
	{22.35,'*8 0 stealth'},

	{22.5,'*1000 80 stealth'},
	{22.6,'*8 0 stealth'},

	{23.0,'*1000 80 stealth'},
	{23.1,'*3 0 stealth'},


	{24.0,'*1000 80 stealth'},
	{24.1,'*3 0 stealth'},

	{25.0,'*1000 80 stealth'},
	{25.1,'*6 0 stealth'},

	{25.5,'*1000 80 stealth'},
	{25.6,'*6 0 stealth'},

	{26.0,'*1000 80 stealth'},
	{26.1,'*2 0 stealth'},


	{32.0,'*1 drunk'},

	--speech2
	{56.0,'*1000 80 stealth'},
	{56.1,'*3 0 stealth'},

	{57.0,'*1000 80 stealth'},
	{57.1,'*6 0 stealth'},

	{57.5,'*1000 80 stealth'},
	{57.6,'*3 0 stealth'},

	{58.25,'*1000 80 stealth'},
	{58.35,'*6 0 stealth'},


	{58.75,'*1000 80 stealth'},
	{58.85,'*6 0 stealth'},

	{59.5,'*1000 80 stealth'},
	{59.6,'*3 0 stealth'},

	{60.5,'*1000 80 stealth'},
	{60.6,'*6 0 stealth'},

	{61.0,'*1000 80 stealth'},
	{61.1,'*6 0 stealth'},

	{61.750,'*1000 80 stealth'},
	{61.850,'*6 0 stealth'},

	{62.50,'*1000 80 stealth'},
	{62.60,'*6 0 stealth'},

	{64.0,'*1 50 drunk,*200 50 stealth,*20 1000 bumpy,*200 0 brake'},
	{64.2,'*0.2 0 stealth'},


	{95.750,'*2000 200 beat'},

	{96.000,'*6 50 tornado'},
	{96.100,'*1 0 tornado'},

	{96.500,'*20 2000 dizzy,*1 50 stealth'},
	--[[
		{96.667,'*6 50 tornado'},
		{96.767,'*1 0 tornado'},

		{97.333,'*6 50 tornado'},
		{97.433,'*1 0 tornado'},

		{98.000,'*6 50 tornado'},
		{98.100,'*1 0 tornado'},

		{98.667,'*6 50 tornado'},
		{98.767,'*1 0 tornado'},

		{99.333,'*6 50 tornado'},
		{99.433,'*1 0 tornado'},

		{100.000,'*6 50 tornado'},
		{100.100,'*1 0 tornado'},

		{100.667,'*6 50 tornado'},
		{100.767,'*1 0 tornado'},

		{101.333,'*6 50 tornado'},
		{101.433,'*1 0 tornado'}, ]]--

	{102.000,'*8 0 dizzy,*0.3 0 stealth,*20 no bumpy,*1 NO DRUNK,*6 0 tornado'},
	{102.100,'*1 0 tornado'},
	--[[
		{102.667,'*6 50 tornado'},
		{102.767,'*1 0 tornado'},

		{103.333,'*6 50 tornado'},
		{103.433,'*1 0 tornado'},

		{104.000,'*6 50 tornado'},
		{104.100,'*1 0 tornado'},

		{104.667,'*6 50 tornado'},
		{104.767,'*1 0 tornado'},

		{105.333,'*6 50 tornado'},
		{105.433,'*1 0 tornado'},

		{106.000,'*6 50 tornado'},
		{106.100,'*1 0 tornado'},

		{106.667,'*6 50 tornado'},
		{106.767,'*1 0 tornado'},

		{107.333,'*6 50 tornado'},
		{107.433,'*1 0 tornado'},

		{108.000,'*6 50 tornado'},
		{108.100,'*1 0 tornado'},

		{108.667,'*6 50 tornado'},
		{108.767,'*1 0 tornado'},

		{109.333,'*6 50 tornado'},
		{109.433,'*1 0 tornado'},

		{110.000,'*6 50 tornado'},
		{110.100,'*1 0 tornado'},

		{110.667,'*6 50 tornado'},
		{110.767,'*1 0 tornado'},

		{111.333,'*6 50 tornado'},
		{111.433,'*1 0 tornado'}, ]]--

	{119.50,'*100 no beat'},

	{120.0,'*1000 2000 bumpy'},
	-- Something makes the holds at this point go twisty in Puurokulho's video,
	-- but there's nothing here or in the update function.  I guess the
	-- uploaded version has different mods than the video. -Kyz
	{128.00,'*1 50 mini,*200 200 drunk,*20000 400 bumpy,*0.5 -50 centered'},
	{128.10,'*1 50 mini,*1 no drunk,*2 no bumpy'},

	{128.50,'*10000 1000 beat'},
	{129.50,'*10000 0 beat'},

	{130.50,'*10000 -1000 beat'},
	{131.50,'*10000 0 beat'},

	{132.50,'*10000 1000 beat'},

	{133.50,'*2 250 centered,*200 0 beat'},
	{134.50,'*10000 -1000 beat'},
	{135.50,'*10000 0 beat'},

	{136.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},

	{136.50,'*10000 1000 beat'},

	{136.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{137.50,'*10000 0 beat'},

	{138.50,'*10000 -1000 beat'},
	{139.50,'*10000 0 beat'},

	{140.50,'*10000 1000 beat'},

	{141.50,'*2 250 centered,*10000 0 beat'},

	{142.50,'*10000 -1000 beat'},
	{143.50,'*10000 0 beat'},

	{144.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{144.50,'*10000 1000 beat'},

	{144.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{145.50,'*10000 0 beat'},

	{146.50,'*10000 -1000 beat'},
	{147.50,'*10000 0 beat'},


	{148.50,'*10000 1000 beat'},

	{149.50,'*2 250 centered,*200000 no beat'},

	{150.50,'*10000 -1000 beat'},
	{151.50,'*10000 0 beat'},

	{152.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{152.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{152.50,'*10000 1000 beat'},
	{153.50,'*10000 0 beat'},

	{154.50,'*10000 -1000 beat'},
	{155.50,'*10000 0 beat'},

	{156.50,'*10000 1000 beat'},

	{157.50,'*2 250 centered,*20000 no beat'},

	{158.50,'*10000 -1000 beat'},
	{159.50,'*10000 0 beat'},

	{160.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{160.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{160.50,'*10000 1000 beat'},
	{161.50,'*10000 0 beat'},

	{162.50,'*10000 -1000 beat'},
	{163.50,'*10000 0 beat'},

	{164.50,'*10000 1000 beat'},


	{165.50,'*2 250 centered,*2000 no beat'},

	{166.50,'*10000 -1000 beat'},
	{167.50,'*10000 0 beat'},

	{168.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{168.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{168.50,'*10000 1000 beat'},
	{169.50,'*10000 0 beat'},

	{170.50,'*10000 -1000 beat'},
	{171.50,'*10000 0 beat'},

	{172.50,'*10000 1000 beat'},

	{173.50,'*2 250 centered,*20000 no beat'},

	{174.50,'*10000 -1000 beat'},
	{175.50,'*10000 0 beat'},

	{176.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{176.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{176.50,'*10000 1000 beat'},
	{177.50,'*10000 0 beat'},

	{178.50,'*10000 -1000 beat'},
	{179.50,'*10000 0 beat'},

	{180.50,'*10000 1000 beat'},

	{181.50,'*2 250 centered,*20000 no beat'},

	{182.50,'*10000 -1000 beat'},
	{183.50,'*10000 0 beat'},

	{184.00,'*1.2 0 centered,*200 200 drunk,*200 400 bumpy'},
	{184.10,'*1.2 0 centered,*1 0 drunk,*2 no bumpy'},

	{184.50,'*10000 1000 beat'},
	{185.50,'*10000 0 beat'},

	{186.50,'*10000 -1000 beat'},
	{187.50,'*10000 0 beat'},

	{188.000,'*40 200 drunk'},
	{188.250,'*40 -200 drunk'},
	{188.500,'*40 200 drunk'},
	{188.750,'*40 -200 drunk'},

	{189.000,'*40 200 drunk'},
	{189.250,'*40 -200 drunk'},
	{189.500,'*40 200 drunk'},
	{189.750,'*40 -200 drunk'},

	{190.000,'*40 200 drunk'},
	{190.250,'*40 -200 drunk'},
	{190.500,'*40 200 drunk'},
	{190.750,'*40 -200 drunk'},

	{191.000,'*40 0 drunk'},
	{191.750,'*40 200 beat,*1 dark'},



	{196.500,'*1 -10 flip'},
	{197.375,'*1 -20 flip'},
	{198.229,'*1 -30 flip'},
	{199.146,'*1 -40 flip'},


	{201.500,'*1 -26.6666666 flip'},
	{202.375,'*1 -13.3333333 flip'},
	{203.229,'*1 0 flip'},






	{253.000,'*1 stealth,*1 dark'},

	{258.0,'*1 80 stealth,*200 120 mini,*200 -200 flip,*1000 1000 bumpy,*1 no dark,*200 0 reverse,*20 0 tipsy,*2 drunk,*200 no centered,*200 no drunk,*200 no beat'},

	{284,'*1 stealth,*1 dark'},
	{285,'*1000 1000 bumpy'},
	{288.0,'*1 no hallway,*20 no reverse,*20 tornado,*1.5 no bumpy,*2000 no flip,*1 80 stealth,*1 no dark,*0.5 no mini'},

	{308.000,'*1 stealth,*3 dark'},

	{312.000,'*800 0.1x,*200 2000 bumpy,*200 stealth,*200 70 reverse,*200 50 hallway,*200 200 brake,*200 no tornado,*1 flip'},
	{312.1000,'*800 2x,*200 500 bumpy,*0.5 70 stealth'},
	{317.1000,'*800 500 tipsy,*200 500 tornado,*200 1000 dizzy'},
	{318.000,'*800 2x,*20 0 bumpy,*20 no reverse,*20 no hallway,*20 no brake,*2 no stealth,*15 no tornado,*15 no dizzy,*30 no tipsy,*2 no dark,*200 no flip'},


	-- BONUS BUG FIX:
	-- Alternating mod resetters.  This section of mods is to reset mods that
	-- alternate every frame in the update function.  In some of them,
	-- Puurokulho forgot a mod in the reset line, so if the alternater ends on
	-- the wrong frame, something is left on for the rest of the song.
	-- Also, it's a fucking mess of mods that weren't turned on being turned
	-- off because he didn't clean up when changing the design. -Kyz
	{327.0,'*800 no stealth,*200 no reverse,*200 1000 no dizzy,*200 no dark,*200 no mini,*2000 2x,*200 no flip'},
	-- Puurokulho forgot to turn off brake.
	{331.5,'*800 no stealth,*200 no tornado,*200 1000 no flip,*200 no dark,*200 2x, *200 no brake'},
	{335.5,'*800 no stealth,*200 no reverse,*200 1000 no dizzy,*200 no dark,*200 no mini,*2000 2x,*200 no flip'},
	{343.0,'*800 no stealth,*200 no bumpy,*200 2x'},
	{347.5,'*800 no stealth,*200 no flip,*200 no invert,*200 2x'},
	{351.5,'*800 no stealth,*200 no flip,*200 no invert,*200 2x'},
	-- Puurokulho forgot to turn off dark.
	{359.0,'*800 no stealth,*200 no flip,*200 no invert,*200 2x,*200 no distant,*200 no dark'},
	-- Puurokulho forgot to turn off dark.  Lucky 'no distant' turns off hallway.
	{363.5,'*800 no stealth,*200 no flip,*200 no invert,*200 2x,*200 no distant,*200 no dark'},
	-- Puurokulho forgot to turn off dark.
	{367.5,'*800 no stealth,*200 no flip,*200 no invert,*200 2x,*200 no distant,*200 no drunk,*200 no dark'},
	-- Puurokulho forgot to turn off brake.
	{375.0,'*800 no stealth,*200 no brake,*200 no tornado,*200 1000 no flip,*200 no dark,*200 2x'},
	{379.5,'*800 no stealth,*200 no bumpy,*200 2x,*2000 no dark'},


	{380.000,'*40 200 drunk'},
	{380.250,'*40 -200 drunk'},
	{380.500,'*40 200 drunk'},
	{380.750,'*40 -200 drunk'},

	{381.000,'*40 200 drunk'},
	{381.250,'*40 -200 drunk'},
	{381.500,'*40 200 drunk'},
	{381.750,'*40 -200 drunk'},

	{382.000,'*40 200 drunk'},
	{382.250,'*40 -200 drunk'},
	{382.500,'*40 200 drunk'},
	{382.750,'*40 -200 drunk'},

	{383.000,'*40 0 drunk'},
	{384.000,'*0.5 50 mini,*0.5 -50 centered,*10 100 beat,*200 200 drunk,*200 400 bumpy'},
	{384.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{389.50,'*2 250 centered'},

	{392.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{392.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{397.50,'*2 250 centered'},

	{400.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{400.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},

	{405.50,'*2 250 centered'},

	{408.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{408.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},


	{413.50,'*2 250 centered'},

	{416.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{416.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},


	{421.50,'*2 250 centered'},

	{424.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{424.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},


	{429.50,'*2 250 centered'},

	{432.00,'*1.2 -50 centered,*200 200 drunk,*200 400 bumpy'},
	{432.10,'*1.2 -50 centered,*1 0 drunk,*2 no bumpy'},


	{437.50,'*2 250 centered'},

	{440.00,'*1.2 0 centered,*200 200 drunk,*200 400 bumpy'},
	{440.10,'*1.2 0 centered,*1 0 drunk,*2 no bumpy,*1 no beat'},



	{447.0,'*1.2 0 centered,*1 0 drunk,*2 no bumpy,*1 no beat,*3 dark,*3 stealth'},
	{448.5,'*1.2 0 centered,*1 0 drunk,*2 no bumpy,*1 no beat,*2 no dark,*2 -100 stealth,*1 blink'},
	---skip to mods
}

--anything eater / timed object manipulation
local cura = 1;
local aorigin = 0;
local anything = {
	{0.0001,},

	{0,'screen','addy',00},
	{0,'screen','skewx',0},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','addy',-00},
	{0,'P1','zoomz',1},
	{0,'jud1','addx',-100},
	{0,'com1','addx',-100},

	{0,'P1','skewx',0},



	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','addy',-00},
	{0,'P2','zoomz',1},
	{0,'jud2','addx',100},
	{0,'com2','addx',100},

	{0,'P2','skewx',0},



	{0.100,},

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',0,50,0},
	{0,'P1','effectperiod',4}, --0.011 for harza bumpy
	{0,'P1','effectclock','bgm'}, 
	{0,'P1','effectoffset',0},

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',0,50,0},
	{0,'P2','effectperiod',4}, --0.011 for harza bumpy
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','effectoffset',0},

	{64.01,},

	{0,'screen','addy',00},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','rotationx',-0},
	{0,'P1','zoomz',0},

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',3,0,0},
	{0,'P1','effectperiod',0.01}, --0.011 for harza bumpy
	{0,'P1','effectclock','timer'}, 
	{0,'P1','effectoffset',0},

	{0,'jud1','wag',},
	{0,'jud1','effectmagnitude',-3,0,0},
	{0,'jud1','effectperiod',0.01},
	{0,'jud1','effectclock','timer'}, 
	{0,'jud1','effectoffset',0},

	{0,'com1','wag',},
	{0,'com1','effectmagnitude',-3,0,0},
	{0,'com1','effectperiod',0.01},
	{0,'com1','effectclock','timer'}, 
	{0,'com1','effectoffset',0},

	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','rotationx',-0},
	{0,'P2','zoomz',0},

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',3,0,0},
	{0,'P2','effectperiod',0.01}, --0.011 for harza bumpy
	{0,'P2','effectclock','timer'}, 
	{0,'P2','effectoffset',0},

	{0,'jud2','wag',},
	{0,'jud2','effectmagnitude',-3,0,0},
	{0,'jud2','effectperiod',0.01},
	{0,'jud2','effectclock','timer'}, 
	{0,'jud2','effectoffset',0},

	{0,'com2','wag',},
	{0,'com2','effectmagnitude',-3,0,0},
	{0,'com2','effectperiod',0.01},
	{0,'com2','effectclock','timer'}, 
	{0,'com2','effectoffset',0},



	{120.0,},

	{0,'screen','addy',00},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','rotationx',-0},
	{0,'P1','zoomz',0},

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',0,3,0},
	{0,'P1','effectperiod',1}, 
	{0,'P1','effectclock','bgm'}, 
	{0,'P1','effectoffset',0},

	{0,'jud1','wag',},
	{0,'jud1','effectmagnitude',0,-3,0},
	{0,'jud1','effectperiod',1},
	{0,'jud1','effectoffset',0},
	{0,'jud1','effectclock','bgm'}, 

	{0,'com1','wag',},
	{0,'com1','effectmagnitude',0,-3,0},
	{0,'com1','effectperiod',1},
	{0,'com1','effectoffset',0},
	{0,'com1','effectclock','bgm'}, 


	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','rotationx',-0},
	{0,'P2','zoomz',0},

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',0,3,0},
	{0,'P2','effectperiod',1}, 
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','effectoffset',0},

	{0,'jud2','wag',},
	{0,'jud2','effectmagnitude',0,-3,0},
	{0,'jud2','effectperiod',1},
	{0,'jud2','effectoffset',0},
	{0,'jud2','effectclock','bgm'}, 

	{0,'com2','wag',},
	{0,'com2','effectmagnitude',0,-3,0},
	{0,'com2','effectperiod',1},
	{0,'com2','effectoffset',0},
	{0,'com2','effectclock','bgm'}, 



	{124.01,},

	{0,'screen','addy',00},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','rotationx',-0},
	{0,'P1','zoomz',0},

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',0,3,0},
	{0,'P1','effectperiod',0.5}, 
	{0,'P1','effectclock','bgm'}, 
	{0,'P1','effectoffset',0},

	{0,'jud1','wag',},
	{0,'jud1','effectmagnitude',0,-3,0},
	{0,'jud1','effectperiod',0.5},
	{0,'jud1','effectoffset',0},
	{0,'jud1','effectclock','bgm'}, 

	{0,'com1','wag',},
	{0,'com1','effectmagnitude',0,-3,0},
	{0,'com1','effectperiod',0.5},
	{0,'com1','effectoffset',0},
	{0,'com1','effectclock','bgm'}, 



	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','rotationx',-0},
	{0,'P2','zoomz',0},

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',0,3,0},
	{0,'P2','effectperiod',0.5}, 
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','effectoffset',0},

	{0,'jud2','wag',},
	{0,'jud2','effectmagnitude',0,-3,0},
	{0,'jud2','effectperiod',0.5},
	{0,'jud2','effectoffset',0},
	{0,'jud2','effectclock','bgm'}, 

	{0,'com2','wag',},
	{0,'com2','effectmagnitude',0,-3,0},
	{0,'com2','effectperiod',0.5},
	{0,'com2','effectoffset',0},
	{0,'com2','effectclock','bgm'}, 




	{127.00,},


	{0,'P1','stopeffect',},
	{0,'jud1','stopeffect',},
	{0,'com1','stopeffect',},

	{0,'P2','stopeffect',},
	{0,'jud2','stopeffect',},
	{0,'com2','stopeffect',},


	---- VIBRATE THINGJAMAGIC
	{128.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P1','zoomz',1},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','zoomz',1},

	{129.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{130.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 


	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{131.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{132.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{136.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{137.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{138.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{139.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{140.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},


	---- VIBRATE THINGJAMAGIC
	{144.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{145.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{146.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{147.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{148.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{152.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 


	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{153.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{154.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{155.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{156.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{160.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{161.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{162.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{163.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{164.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},
	---- VIBRATE THINGJAMAGIC
	{168.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 



	{169.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{170.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{171.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{172.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{176.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{177.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{178.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{179.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{180.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{184.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{185.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{186.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{187.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{188.00,},

	{0,'P1','stopeffect',},
	{0,'P2','stopeffect',},

	{187.00,}, ------MOVE TOPSCREEN

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','addx',-SCREEN_CENTER_X},
	{0,'P1','addy',-SCREEN_CENTER_Y},
	{0,'P1','zoomz',1},

	{0,'P1','skewx',0},

	{0,'P1','z',0},

	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','addx',-SCREEN_CENTER_X},
	{0,'P2','addy',-SCREEN_CENTER_Y},
	{0,'P2','zoomz',1},

	{0,'P2','skewx',0},
	{0,'P2','z',0},

	{0,'songbg','addx',-SCREEN_CENTER_X},
	{0,'songbg','addy',-SCREEN_CENTER_Y},

	{0,'songfg','addx',-SCREEN_CENTER_X},
	{0,'songfg','addy',-SCREEN_CENTER_Y},


	{0,'screen','x',0},

	{0,'screen','y',0},

	{196.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-10},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-20},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-30},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-40},

	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.13},
	{0,'P1','rotationx',-10},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.16},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.27},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.31},

	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.13},
	{0,'P2','rotationx',-10},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.16},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.27},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.31},


	{201.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-25},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',-15},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',0},

	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.20},
	{0,'P1','rotationx',-10},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',-0.16},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0},
	{0,'P1','rotationx',0},

	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.20},
	{0,'P2','rotationx',-10},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',-0.16},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0},
	{0,'P2','rotationx',0},


	{205.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',-10},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',-20},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',-30},


	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',-10},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',-20},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',-30},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',-10},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',-20},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',-30},


	{213.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',-20},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',-10},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',0},


	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',-20},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',-10},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',0},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',-20},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',-10},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',0},

	{217.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.8},
	{0,'screen','rotationz',10},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.6},
	{0,'screen','rotationz',20},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.4},
	{0,'screen','rotationz',30},

	{221.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.6},
	{0,'screen','rotationz',20},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.8},
	{0,'screen','rotationz',10},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',1},
	{0,'screen','rotationz',0},

	{229.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',13.3333333},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',26.6666666},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',40},

	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0.15},
	{0,'P1','rotationx',10},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0.23},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0.31},

	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0.15},
	{0,'P2','rotationx',10},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0.23},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0.31},

	{233.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',26.6666666},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',13.3333333},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationx',0},

	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0.23},
	{0,'P1','rotationx',0},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0.15},
	{0,'P1','decelerate',0.3},
	{0,'P1','skewx',0},

	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0.23},
	{0,'P2','rotationx',0},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0.15},
	{0,'P2','decelerate',0.3},
	{0,'P2','skewx',0},

	{237.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',10},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',20},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',30},


	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',10},
	{0,'P1','rotationy',10},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',20},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',30},


	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',10},
	{0,'P2','rotationy',10},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',20},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',30},


	{245.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',20},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',10},
	{0,'screen','decelerate',0.3},
	{0,'screen','rotationy',0},


	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',20},
	{0,'P1','rotationy',0},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',10},

	{0,'P1','decelerate',0.3},
	{0,'P1','rotationz',0},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',20},
	{0,'P2','rotationy',0},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',10},

	{0,'P2','decelerate',0.3},
	{0,'P2','rotationz',0},

	{249.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.8},
	{0,'screen','rotationz',-10},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.6},
	{0,'screen','rotationz',-20},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.4},
	{0,'screen','rotationz',-30},

	{253.50,}, ------MOVE TOPSCREEN


	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.6},
	{0,'screen','rotationz',-20},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',0.8},
	{0,'screen','rotationz',-10},
	{0,'screen','decelerate',0.3},
	{0,'screen','zoom',1},
	{0,'screen','rotationz',0},

	{258.01,},

	{0,'screen','addx',-SCREEN_CENTER_X},
	{0,'screen','addy',-SCREEN_CENTER_Y},

	{0,'songbg','addx',SCREEN_CENTER_X},
	{0,'songbg','addy',SCREEN_CENTER_Y},

	{0,'songfg','addx',SCREEN_CENTER_X},
	{0,'songfg','addy',SCREEN_CENTER_Y},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','y',SCREEN_CENTER_Y},
	{0,'P1','zoomz',10},


	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','y',SCREEN_CENTER_Y},
	{0,'P2','zoomz',10},


	{288.01,},

	{0,'screen','addy',00},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','y',SCREEN_CENTER_Y},
	{0,'P1','linear',0},
	{0,'P1','zoomz',0},

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',0,10,0},
	{0,'P1','effectperiod',0.01}, --0.011 for harza bumpy
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','timer'},

	{0,'jud1','wag',},
	{0,'jud1','effectmagnitude',0,-10,0},
	{0,'jud1','effectperiod',0.01},
	{0,'jud1','effectoffset',0},
	{0,'jud1','effectclock','timer'},

	{0,'com1','wag',},
	{0,'com1','effectmagnitude',0,-10,0},
	{0,'com1','effectperiod',0.01},
	{0,'com1','effectoffset',0},
	{0,'com1','effectclock','timer'},


	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','y',SCREEN_CENTER_Y},
	{0,'P2','linear',0},
	{0,'P2','zoomz',0},

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',0,10,0},
	{0,'P2','effectperiod',0.01}, --0.011 for harza bumpy
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','timer'},

	{0,'jud2','wag',},
	{0,'jud2','effectmagnitude',0,-10,0},
	{0,'jud2','effectperiod',0.01},
	{0,'jud2','effectoffset',0},
	{0,'jud2','effectclock','timer'},

	{0,'com2','wag',},
	{0,'com2','effectmagnitude',0,-10,0},
	{0,'com2','effectperiod',0.01},
	{0,'com2','effectoffset',0},
	{0,'com2','effectclock','timer'},


	{312.01,},

	{0,'screen','addy',00},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','y',SCREEN_CENTER_Y},
	{0,'P1','linear',0},
	{0,'P1','zoomz',9},
	{0,'P1','zoomx',2},
	{0,'P1','zoomy',2},

	{0,'P1','stopeffect',},

	{0,'jud1','stopeffect',},
	{0,'com1','stopeffect',},


	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','y',SCREEN_CENTER_Y},
	{0,'P2','linear',0},
	{0,'P2','zoomz',9},
	{0,'P2','zoomx',2},
	{0,'P2','zoomy',2},

	{0,'P2','stopeffect',},

	{0,'jud2','stopeffect',},
	{0,'com2','stopeffect',},



	{318.01,},

	{0,'P1','zoomz',1},
	{0,'P1','zoomx',1},
	{0,'P1','zoomy',1},

	{0,'P2','zoomz',1},
	{0,'P2','zoomx',1},
	{0,'P2','zoomy',1},


	---- VIBRATE THINGJAMAGIC
	{384.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P1','zoomz',1},

	{0,'P1','decelerate',1},
	{0,'P1','rotationz',-30},



	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','zoomz',1},
	{0,'P2','decelerate',1},
	{0,'P2','rotationz',-30},

	{385.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{386.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{387.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{388.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{392.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P1','zoomz',1},
	{0,'P1','decelerate',1},
	{0,'P1','rotationz',30},


	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{0,'P2','zoomz',1},
	{0,'P2','decelerate',1},
	{0,'P2','rotationz',30},



	{393.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{394.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{395.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{396.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{400.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 



	{0,'P1','decelerate',1},
	{0,'P1','rotationz',-30},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{0,'P2','decelerate',1},
	{0,'P2','rotationz',-30},


	{401.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{402.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{403.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{404.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},


	---- VIBRATE THINGJAMAGIC
	{408.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P1','decelerate',1},
	{0,'P1','rotationz',30},


	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{0,'P2','decelerate',1},
	{0,'P2','rotationz',30},

	{409.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{410.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{411.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{412.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{416.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P1','decelerate',1},
	{0,'P1','rotationz',-30},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 


	{0,'P2','decelerate',1},
	{0,'P2','rotationz',-30},


	{417.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{418.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{419.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{420.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{424.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 


	{0,'P1','decelerate',1},
	{0,'P1','rotationz',30},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{0,'P2','decelerate',1},
	{0,'P2','rotationz',30},


	{425.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{426.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{427.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{428.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{432.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 


	{0,'P1','decelerate',1},
	{0,'P1','rotationz',-30},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{0,'P2','decelerate',1},
	{0,'P2','rotationz',-30},


	{433.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 
	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{434.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{435.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{436.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},

	---- VIBRATE THINGJAMAGIC
	{440.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-20,20,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 


	{0,'P1','decelerate',1},
	{0,'P1','rotationz',0},

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-20,20,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 
	{0,'P2','decelerate',1},
	{0,'P2','rotationz',0},


	{441.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-15,15,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-15,15,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{442.00,},

	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-10,10,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-10,10,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{443.00,},


	{0,'P1','vibrate',},
	{0,'P1','effectmagnitude',-5,5,0},
	{0,'P1','effectperiod',0.5},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','vibrate',},
	{0,'P2','effectmagnitude',-5,5,0},
	{0,'P2','effectperiod',0.5},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	{444.00,},

	{0,'P1','stopeffect',},

	{0,'P2','stopeffect',},


	{448.00,},

	{0,'P1','x',SCREEN_CENTER_X},
	{0,'P1','addx',-SCREEN_CENTER_X},
	{0,'P1','addy',-SCREEN_CENTER_Y},
	{0,'P1','zoomz',1},

	{0,'P1','skewx',0},

	{0,'P1','z',0},

	{0,'P2','x',SCREEN_CENTER_X},
	{0,'P2','addx',-SCREEN_CENTER_X},
	{0,'P2','addy',-SCREEN_CENTER_Y},
	{0,'P2','zoomz',1},

	{0,'P2','skewx',0},

	{0,'P2','z',0},

	{0,'songbg','addx',-SCREEN_CENTER_X},
	{0,'songbg','addy',-SCREEN_CENTER_Y},

	{0,'songfg','addx',-SCREEN_CENTER_X},
	{0,'songfg','addy',-SCREEN_CENTER_Y},


	{0,'screen','x',0},

	{0,'screen','y',0},

	{0,'screen','wag',},
	{0,'screen','effectmagnitude',35,0,0},
	{0,'screen','effectperiod',4},
	{0,'screen','effectoffset',1},
	{0,'screen','effectclock','bgm'}, 

	{0,'P1','wag',},
	{0,'P1','effectmagnitude',0,0,35},
	{0,'P1','effectperiod',4},
	{0,'P1','effectoffset',0},
	{0,'P1','effectclock','bgm'}, 

	{0,'P2','wag',},
	{0,'P2','effectmagnitude',0,0,35},
	{0,'P2','effectperiod',4},
	{0,'P2','effectoffset',0},
	{0,'P2','effectclock','bgm'}, 

	--[[
		{32.00,},


		{0,'P1','pulse',},
		{0,'P1','effectmagnitude',1,0.8,0},
		{0,'P1','effectclock','bgm'},
		{0,'P1','effectperiod',1},
		{0,'P1','effectoffset',0},

		{0,'P2','pulse',},
		{0,'P2','effectmagnitude',1,0.8,0},
		{0,'P2','effectclock','bgm'},
		{0,'P2','effectperiod',1}, ]]--
}

--choose to skip anything in the previous table
local anythingskip= {}
--SCREAMING GUMBALL / timed message broadcaster
local curmessage= 1
--{beat,message,ignoreIfAhead}
local messages= {}


local function update(self, delta)
	local screen= SCREENMAN:GetTopScreen()
	local curr_song_beat= GAMESTATE:GetSongBeat()
	if curr_song_beat>=0.1 and not checked then
		if screen:GetChild('PlayerP1') then p1on = true; else p1on = false; end
		if screen:GetChild('PlayerP2') then p2on = true; else p2on = false; end

		for pname in ivalues{'P1', 'P2'} do
			thing_actors[pname]= screen:GetChild('Player'..pname)
			if thing_actors[pname] then
				for cj in ivalues{{'jud1', 'Judgment'}, {'jud2', 'Combo'}} do
					thing_actors[cj[1]]= thing_actors[pname]:GetChild(cj[2])
				end
			end
			for name in ivalues{'Life', 'Score'} do
				local acname= name .. pname
				thing_actors[acname]= screen:GetChild(acname)
			end
			for name in ivalues{'BPMDisplay', 'LifeFrame', 'ScoreFrame', 'Lyrics',
				'SongForeground', 'SongBackground', 'Overlay', 'Underlay'} do
				thing_actors[name]= screen:GetChild(name)
			end
		end
		modEffect = 1;
		skewdir = -0.1;
		p1skew = 0.1;
		thing_actors.screen = screen;
		thing_actors.songfg = screen:GetChild('SongForeground')
		thing_actors.songbg = screen:GetChild('SongBackground')
		checked = true;
	end

	if curr_song_beat>=0.115 and fgcurcommand == 1 then
		
		
		screen:GetChild('Overlay'):visible(false);

		if screen:GetChild('LifeFrame') then
			screen:GetChild('LifeFrame'):y(-9999); end
		if screen:GetChild('BPMDisplay') then
			screen:GetChild('BPMDisplay'):y(-9999); end
		
		
		

		if GAMESTATE:IsHumanPlayer(PLAYER_1) then
			

			screen:GetChild('LifeP1'):visible(false);
			screen:GetChild('ScoreP1'):visible(false);

		end
		
		if screen:GetChild('PlayerP2') then
			

			screen:GetChild('LifeP2'):visible(false);
			screen:GetChild('ScoreP2'):visible(false);

		end
		fgcurcommand = fgcurcommand + 1;
	end


	
	
	local beat = curr_song_beat
	--[[		
		if beat>320 and beat<420 then

		P1:skewx(p1skew)
		p1skew = p1skew + skewdir;
		if p1skew == 5 or p1skew == -5 then skewdir = skewdir* -1; end

		end ]]--

	---skip to frames

	if beat>320 and beat<326.9 then

		if modEffect == 1 then
			mod_both('*2000 80 stealth,*200 20 flip,*200 -200 mini,*200 1x,*200 dark,*200 500 beat');
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no flip,*2000 no mini,*2000 no stealth,*2000 no dark');
			modEffect = 1;
		end
	end

	if beat>328 and beat<331.4 then

		if modEffect == 1 then
			mod_both('*2000 80 stealth,*2000 -100 tornado,*200 flip,*200 dark,*2000 0.5x;,*200 200 brake');
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no stealth,*2000 no brake,*2000 no reverse,*200 no dark,*200 no flip,*200 no tornado');
			modEffect = 1;
		end
	end



	if beat>332.0 and beat<335.4 then

		if modEffect == 1 then
			mod_both('*10000 2x,*2000 80 stealth,*2000 no dizzy,*2000 reverse,*200 dark');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no stealth,*2000 no dizzy,*2000 no reverse,*200 no dark');
			
			modEffect = 1;
		end
	end


	if beat>336.0 and beat<342.9 then

		if modEffect == 1 then
			mod_both('*10000 0.5x,*200 900 bumpy,*200 80 stealth');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no bumpy,*200 no stealth');
			
			modEffect = 1;
		end
	end

	if beat>344.0 and beat<347.4 then

		if modEffect == 1 then
			mod_both('*10000 100 flip,*200 80 stealth');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no tipsy,*200 no stealth,*200 no flip');
			
			modEffect = 1;
		end
	end

	if beat>348.0 and beat<351.4 then

		if modEffect == 1 then
			mod_both('*10000 100 invert,*200 80 stealth');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no tipsy,*200 no stealth,*200 no invert');
			
			modEffect = 1;
		end
	end



	if beat>352.0 and beat<358.9 then

		if modEffect == 1 then
			mod_both('*10000 200 distant,*200 80 stealth,*200 dark');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 no distant,*200 0 stealth,*200 no dark');
			
			modEffect = 1;
		end
	end

	if beat>360.0 and beat<363.4 then

		if modEffect == 1 then
			mod_both('*10000 200 hallway,*200 80 stealth,*200 dark');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 no hallway,*200 0 stealth,*200 no dark');
			
			modEffect = 1;
		end
	end

	if beat>364.0 and beat<367.4 then

		if modEffect == 1 then
			mod_both('*10000 2x,*20000 500 drunk,*200 80 stealth,*200 dark');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 no hallway,*200 0 stealth,*200 no dark,*20000 2x,*200 0 drunk');
			
			modEffect = 1;
		end
	end


	if beat>368.0 and beat<374.9 then

		if modEffect == 1 then
			mod_both('*2000 80 stealth,*2000 -100 tornado,*200 flip,*200 dark,*2000 0.5x;,*200 200 brake');
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*2000 no stealth,*2000 no brake,*2000 no reverse,*200 no dark,*200 no flip,*200 no tornado');
			modEffect = 1;
		end
	end


	if beat>376.0 and beat<379.4 then

		if modEffect == 1 then
			mod_both('*10000 0.5x,*20000 2000 bumpy,*200 80 stealth');
			
			modEffect = 2;
		elseif modEffect == 2 then
			mod_both('*10000 2x,*200000 no bumpy,*200 no stealth');
			
			modEffect = 1;
		end
	end
	
	---------------------------------------------------------------------------------------
	----------------------DON'T TOUCH IT KIDDO---------------------------------------------
	---------------------------------------------------------------------------------------
	
	local disable = false;
	if disable ~= true then
		
		--custom mod reader (c) 2012 #taronuke #yolo #swag #swag #amazon.co.jp #teamproofofconcept #swag
		while curmod<=table.getn(mods) and curr_song_beat>=mods[curmod][1] do
			if table.getn(mods[curmod]) == 3 then
				apply_mod(mods[curmod][2],mods[curmod][3]);
			else
				mod_both(mods[curmod][2]);
			end
			curmod = curmod+1;
		end
		
		--SCREAMING GUMBALL
		while curmessage<=table.getn(messages) and curr_song_beat>=messages[curmessage][1] do
			if messages[curmessage][3] and curr_song_beat>=messages[curmessage][1]+5 then
				curmessage = curmessage+1;
			else
				MESSAGEMAN:Broadcast(messages[curmessage][2]);
				curmessage = curmessage+1;
			end
		end
		
		if anything[cura] and anything[cura][1] and anything[cura][1] > aorigin then aorigin = anything[cura][1]; end
		
		--ANYTHING EATER (c) 2013 #taronuke #yolo #swag #swag #amazon.co.jp #teamproofofconcept #swag
		while checked and cura<=table.getn(anything) and anything[cura] and curr_song_beat>=anything[cura][1] do
			--SCREENMAN:SystemMessage('run '..anything[cura][3]..' on '..anything[cura][2]);
			local thing_entry= anything[cura]
			if curr_song_beat>aorigin+5 and thing_entry[2] == 'P1' then
				cura = cura+1;
			else
				if thing_entry[2] == 'SystemMessage' then
					SCREENMAN:SystemMessage(thing_entry[3])
				elseif thing_actors[thing_entry[2]] and thing_entry[3] then
					local actor= thing_actors[thing_entry[2]]
					local func= actor[thing_entry[3]]
					if func then func(actor, thing_entry[4], thing_entry[5], thing_entry[6], thing_entry[7]) end
				end
				cura = cura+1;
			end
		end
	end
end

return Def.ActorFrame{
  Name= "actor_j",
  OnCommand= function(self)
		self:SetUpdateFunction(update)
		songName = GAMESTATE:GetCurrentSong():GetSongDir();
	end,
  Def.Quad{
    Name= "actor_k",
    InitCommand= cmd(visible,true),
    OnCommand= cmd(sleep,1000),
  },
  Def.ActorFrame{
    Name= "actor_l",
    OnCommand= cmd(fov,100),
    Def.Sprite{
      Name= "actor_m",
      Frames= {
        {Frame= 0, Delay= 0.0333},
        {Frame= 1, Delay= 0.0333},
        {Frame= 2, Delay= 0.0333},
        {Frame= 3, Delay= 0.0333},
    },
      OnCommand= cmd(hibernate,74.067;
						x,SCREEN_CENTER_X;z,50;
						y,SCREEN_CENTER_Y;
						zoomtoheight,SCREEN_HEIGHT;
						zoomtowidth,SCREEN_WIDTH;
						diffusealpha,0.5;
						decelerate,0.3;
						diffusealpha,0.3;
						sleep,0;
						diffusealpha,0.5;
						decelerate,0.3;
						diffusealpha,0.3;
						sleep,0;
						diffusealpha,0.5;
						decelerate,0.3;
						diffusealpha,0.3;
						sleep,0;
						diffusealpha,0.5;
						decelerate,0.5;
						diffusealpha,0;
						sleep,0.324;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.5;
							diffusealpha,0;
							sleep,0.379;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.5;
								diffusealpha,0;
								sleep,0.379),
      Texture= "./static 4x1.png",
    },
    Def.Sprite{
      Name= "actor_n",
      Frames= {
        {Frame= 0, Delay= 0.0333},
        {Frame= 1, Delay= 0.0333},
        {Frame= 2, Delay= 0.0333},
        {Frame= 3, Delay= 0.0333},
    },
      OnCommand= cmd(hibernate,79.929;z,50;
						x,SCREEN_CENTER_X;
						y,SCREEN_CENTER_Y;
						zoomtoheight,SCREEN_HEIGHT;
						zoomtowidth,SCREEN_WIDTH;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.5;
							diffusealpha,0;
							sleep,0.379;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.5;
								diffusealpha,0;
								sleep,0.2;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.5;
									diffusealpha,0;
									sleep,0.379),
      Texture= "./static 4x1.png",
    },
    Def.Sprite{
      Name= "actor_o",
      Frames= {
        {Frame= 0, Delay= 0.0333},
        {Frame= 1, Delay= 0.0333},
        {Frame= 2, Delay= 0.0333},
        {Frame= 3, Delay= 0.0333},
    },
      OnCommand= cmd(hibernate,85.446;z,50;
						x,SCREEN_CENTER_X;
						y,SCREEN_CENTER_Y;
						zoomtoheight,SCREEN_HEIGHT;
						zoomtowidth,SCREEN_WIDTH;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.5;
							diffusealpha,0;
							sleep,0.379;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.5;
								diffusealpha,0;
								sleep,0.2;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.5;
									diffusealpha,0;
									sleep,0.379),
      Texture= "./static 4x1.png",
    },
    Def.Sprite{
      Name= "actor_p",
      Frames= {
        {Frame= 0, Delay= 0.0333},
        {Frame= 1, Delay= 0.0333},
        {Frame= 2, Delay= 0.0333},
        {Frame= 3, Delay= 0.0333},
    },
      OnCommand= cmd(hibernate,90.963;z,50;
						x,SCREEN_CENTER_X;
						y,SCREEN_CENTER_Y;
						zoomtoheight,SCREEN_HEIGHT;
						zoomtowidth,SCREEN_WIDTH;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.3;
							diffusealpha,0.3;
							sleep,0;
							diffusealpha,0.5;
							decelerate,0.5;
							diffusealpha,0;
							sleep,0.379;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.3;
								diffusealpha,0.3;
								sleep,0;
								diffusealpha,0.5;
								decelerate,0.5;
								diffusealpha,0;
								sleep,0.2;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.3;
									diffusealpha,0.3;
									sleep,0;
									diffusealpha,0.5;
									decelerate,0.5;
									diffusealpha,0;
									sleep,0.379),
      Texture= "./static 4x1.png",
    },
  },
}
